==> pythonic-dbm-0.5.0.tar.gz: pythonic-dbm-0.5.0/tests/models/test_base.py <==
import datetime as datetime

import pytest

from pydbm import DbmModel
from pydbm.exceptions import EmptyModelError


class Model(DbmModel):
    bool: bool
    bytes: bytes
    date: datetime.date
    datetime: datetime.datetime
    float: float
    int: int
    none: None
    str: str


def test_base_slots():
    assert DbmModel.__slots__ == ("_pk", "fields", "id")


def test_base_init():
    model = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )

    assert model.bool is True
    assert model.bytes == b"123"
    assert model.date == datetime.date(2020, 1, 1)
    assert model.datetime == datetime.datetime(2020, 1, 1, 2, 10, 40)
    assert model.float == 1.0
    assert model.int == 1
    assert model.none is None
    assert model.str == "str"

    assert model.pk == model.id
    assert model.pk == "552eb2e66df095304137be35af85aaed"
    assert model.fields == {
        "bool": True,
        "bytes": b"123",
        "date": datetime.date(2020, 1, 1),
        "datetime": datetime.datetime(2020, 1, 1, 2, 10, 40),
        "float": 1.0,
        "int": 1,
        "none": None,
        "str": "str",
    }


def test_base_repr():
    model = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )

    assert repr(model) == "Model(bool=True, bytes=b'123', date=datetime.date(2020, 1, 1), datetime=datetime.datetime(2020, 1, 1, 2, 10, 40), float=1.0, int=1, none=None, str='str')"  # noqa: E501


def test_base_eq():
    model_1 = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )
    model_2 = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )

    assert model_1 == model_2

    model_3 = Model(
        bool=False,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )
    assert model_1 != model_3
    assert model_2 != model_3


def test_base_hash():
    class Account(DbmModel):
        ids: int
        name: str

    accounts = {
        Account(ids=1, name="John"),
        Account(ids=1, name="John"),
        Account(ids=2, name="Jane"),
    }

    assert accounts == {Account(ids=1, name="John"), Account(ids=2, name="Jane")}


@pytest.mark.parametrize(
    "field_type, field_value",
    [
        (bool, True),
        (bytes, b"123"),
        (datetime.date, datetime.date(2020, 1, 1)),
        (datetime.datetime, datetime.datetime(2020, 1, 1, 2, 10, 40)),
        (float, 1.0),
        (int, 1),
        (None, None),
        (str, "str"),
    ],
)
def test_base_save(teardown_db, field_type, field_value):
    example_model: DbmModel = type("Example", (DbmModel,), {"__annotations__": {"field": field_type}})  # type: ignore

    model = example_model(field=field_value)
    assert model.save() is None

    model = example_model.objects.get(pk=model.id)
    assert model.field == field_value


def test_base_create(teardown_db):
    class Example(DbmModel):
        str: str

    assert Example.objects.create(str="str") == Example(str="str")


def test_base_get(teardown_db):
    class Example(DbmModel):
        str: str

    model = Example.objects.create(str="str")

    assert Example.objects.get(pk=model.pk) == model


def test_base_delete(teardown_db):
    class Example(DbmModel):
        str: str

    model = Example.objects.create(str="str")

    model.delete()
    with pytest.raises(model.DoesNotExists) as cm:
        Example.objects.get(pk=model.id)
    assert str(cm.value) == "Example with pk 341be97d9aff90c9978347f66f945b77 does not exists"


def test_base_update(teardown_db):
    class Example(DbmModel):
        str: str

    model = Example.objects.create(str="str")
    model.update(str="new_str")

    assert model.str == "new_str"
    assert Example.objects.get(pk=model.pk).str == "new_str"


def test_base_all(teardown_db):
    class Example(DbmModel):
        str: str

    assert Example.objects.create(str="str") == Example(str="str")
    assert Example.objects.create(str="another str") == Example(str="another str")

    assert list(Example.objects.all()) == [Example(str="another str"), Example(str="str")]


def test_base_filter(teardown_db):
    class Example(DbmModel):
        str: str

    Example.objects.create(str="str")
    Example.objects.create(str="another str")

    assert list(Example.objects.filter(str="str")) == [Example(str="str")]


def test_base_empty_model():
    with pytest.raises(EmptyModelError) as cm:
        class EmptyModel(DbmModel):
            pass

    assert str(cm.value) == "Empty model is not allowed."


def test_base_update_obj_on_db_when_updating_the_field_on_the_instance():
    class Model(DbmModel):
        username: str

    model = Model(username="username")
    model.save()

    model.username = "new_username"
    model.save()

    assert Model.objects.get(pk=model.pk) == Model(username="new_username")


def test_base_count():
    class Model(DbmModel):
        username: str

    assert Model.objects.count() == 0

    Model(username="hakan").save()
    assert Model.objects.count() == 1

    Model(username="celik").save()
    assert Model.objects.count() == 2

==> pythonic-dbm-0.5.1.tar.gz: pythonic-dbm-0.5.1/tests/models/test_base.py <==
import datetime as datetime

import pytest

from pydbm import DbmModel
from pydbm.exceptions import EmptyModelError


class Model(DbmModel):
    bool: bool
    bytes: bytes
    date: datetime.date
    datetime: datetime.datetime
    float: float
    int: int
    none: None
    str: str


def test_base_slots():
    assert DbmModel.__slots__ == ("_pk", "fields", "id")


def test_base_init():
    model = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )

    assert model.bool is True
    assert model.bytes == b"123"
    assert model.date == datetime.date(2020, 1, 1)
    assert model.datetime == datetime.datetime(2020, 1, 1, 2, 10, 40)
    assert model.float == 1.0
    assert model.int == 1
    assert model.none is None
    assert model.str == "str"

    assert model.pk == model.id
    assert model.pk == "552eb2e66df095304137be35af85aaed"
    assert model.fields == {
        "bool": True,
        "bytes": b"123",
        "date": datetime.date(2020, 1, 1),
        "datetime": datetime.datetime(2020, 1, 1, 2, 10, 40),
        "float": 1.0,
        "int": 1,
        "none": None,
        "str": "str",
    }


def test_base_repr():
    model = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )

    assert repr(model) == "Model(bool=True, bytes=b'123', date=datetime.date(2020, 1, 1), datetime=datetime.datetime(2020, 1, 1, 2, 10, 40), float=1.0, int=1, none=None, str='str')"  # noqa: E501


def test_base_eq():
    model_1 = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )
    model_2 = Model(
        bool=True,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )

    assert model_1 == model_2

    model_3 = Model(
        bool=False,
        bytes=b"123",
        date=datetime.date(2020, 1, 1),
        datetime=datetime.datetime(2020, 1, 1, 2, 10, 40),
        float=1.0,
        int=1,
        none=None,
        str="str",
    )
    assert model_1 != model_3
    assert model_2 != model_3


def test_base_hash():
    class Account(DbmModel):
        ids: int
        name: str

    accounts = {
        Account(ids=1, name="John"),
        Account(ids=1, name="John"),
        Account(ids=2, name="Jane"),
    }

    assert accounts == {Account(ids=1, name="John"), Account(ids=2, name="Jane")}


@pytest.mark.parametrize(
    "field_type, field_value",
    [
        (bool, True),
        (bytes, b"123"),
        (datetime.date, datetime.date(2020, 1, 1)),
        (datetime.datetime, datetime.datetime(2020, 1, 1, 2, 10, 40)),
        (float, 1.0),
        (int, 1),
        (None, None),
        (str, "str"),
    ],
)
def test_base_save(teardown_db, field_type, field_value):
    example_model: DbmModel = type("Example", (DbmModel,), {"__annotations__": {"field": field_type}})  # type: ignore

    model = example_model(field=field_value)
    assert model.save() is None

    model = example_model.objects.get(pk=model.id)
    assert model.field == field_value


def test_base_create(teardown_db):
    class Example(DbmModel):
        str: str

    assert Example.objects.create(str="str") == Example(str="str")


def test_base_get(teardown_db):
    class Example(DbmModel):
        str: str

    model = Example.objects.create(str="str")

    assert Example.objects.get(pk=model.pk) == model


def test_base_delete(teardown_db):
    class Example(DbmModel):
        str: str

    model = Example.objects.create(str="str")

    model.delete()
    with pytest.raises(model.DoesNotExists) as cm:
        Example.objects.get(pk=model.id)
    assert str(cm.value) == "Example with pk 341be97d9aff90c9978347f66f945b77 does not exists"


def test_base_update(teardown_db):
    class Example(DbmModel):
        str: str

    model = Example.objects.create(str="str")
    model.update(str="new_str")

    assert model.str == "new_str"
    assert Example.objects.get(pk=model.pk).str == "new_str"


def test_base_all_and_filter(teardown_db):
    class Example(DbmModel):
        field1: str
        field2: int

    assert Example.objects.create(field1="str", field2=1) == Example(field1="str", field2=1)
    assert Example.objects.create(field1="another str", field2=2) == Example(field1="another str", field2=2)
    assert len(list(Example.objects.all())) == Example.objects.count()
    assert list(Example.objects.all()) == [Example(field1="another str", field2=2), Example(field1="str", field2=1)]
    assert list(Example.objects.filter()) == [Example(field1="another str", field2=2), Example(field1="str", field2=1)]
    assert list(Example.objects.filter(field2=1)) == [Example(field1="str", field2=1)]


def test_base_filter(teardown_db):
    class Example(DbmModel):
        str: str

    Example.objects.create(str="str")
    Example.objects.create(str="another str")

    assert list(Example.objects.filter(str="str")) == [Example(str="str")]


def test_base_empty_model():
    with pytest.raises(EmptyModelError) as cm:
        class EmptyModel(DbmModel):
            pass

    assert str(cm.value) == "Empty model is not allowed."


def test_base_update_obj_on_db_when_updating_the_field_on_the_instance():
    class Model(DbmModel):
        username: str

    model = Model(username="username")
    model.save()

    model.username = "new_username"
    model.save()

    assert Model.objects.get(pk=model.pk) == Model(username="new_username")


def test_base_count():
    class Model(DbmModel):
        username: str

    assert Model.objects.count() == 0

    Model(username="hakan").save()
    assert Model.objects.count() == 1

    Model(username="celik").save()
    assert Model.objects.count() == 2
